┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphinviewcontainer.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dolphinviewcontainer.h')
-rw-r--r--src/dolphinviewcontainer.h12
1 files changed, 8 insertions, 4 deletions
diff --git a/src/dolphinviewcontainer.h b/src/dolphinviewcontainer.h
index 3c5270a6e..da317761b 100644
--- a/src/dolphinviewcontainer.h
+++ b/src/dolphinviewcontainer.h
@@ -180,11 +180,15 @@ private slots:
/**
* Opens the context menu on the current mouse position.
* @item File item context. If item is 0, the context menu
* should be applied to \a url.
* @url URL which contains \a item.
*/
- void openContextMenu(const KFileItem& item, const KUrl& url);
+ void openContextMenu(const KFileItem& item,
+ const KUrl& url,
+ const QList<QAction*>& customActions);
/**
* Saves the position of the contents to the
@@ -180,11 +180,15 @@ private slots:
/**
* Opens the context menu on the current mouse position.
- * @item File item context. If item is 0, the context menu
- * should be applied to \a url.
- * @url URL which contains \a item.
+ * @item File item context. If item is null, the context menu
+ * should be applied to \a url.
+ * @url URL which contains \a item.
+ * @customActions Actions that should be added to the context menu,
+ * if the file item is null.
*/